@@ -8,13 +8,14 @@ use {
         errors::*,
         file_sum,
         icon::*,
-        path,
         pattern::SearchModeMap,
+        path::SpecialPaths,
         skin::ExtColorMap,
         syntactic::SyntaxTheme,
         tree::TreeOptions,
         verb::*,
     },
+    crokey::crossterm::tty::IsTty,
     std::{
         convert::{TryFrom, TryInto},
         io,
@@ -26,6 +27,9 @@ use {
 /// for the whole life of the App
 pub struct AppContext {
 
+    /// Whether the application is running in a normal TTY context
+    pub is_tty: bool,
+
     /// The initial tree root
     pub initial_root: PathBuf,
 
@@ -50,7 +54,7 @@ pub struct AppContext {
     pub verb_store: VerbStore,
 
     /// the paths for which there's a special behavior to follow (comes from conf)
-    pub special_paths: Vec<path::SpecialPath>,
+    pub special_paths: SpecialPaths,
 
     /// the map between search prefixes and the search mode to apply
     pub search_modes: SearchModeMap,
@@ -108,6 +112,12 @@ pub struct AppContext {
 
     /// whether to sync broot's work dir with the current panel's root
     pub update_work_dir: bool,
+
+    /// Whether Kitty keyboard enhancement flags are pushed, so that
+    /// we know whether we need to temporarily disable them during
+    /// the execution of a terminal program.
+    /// This is determined by app::run on launching the event source.
+    pub keyboard_enhanced: bool,
 }
 
 impl AppContext {
@@ -116,6 +126,7 @@ impl AppContext {
         verb_store: VerbStore,
         config: &Conf,
     ) -> Result<Self, ProgramError> {
+        let is_tty = std::io::stdout().is_tty();
         let config_default_args = config
             .default_flags
             .as_ref()
@@ -130,11 +141,8 @@ impl AppContext {
         };
         let icons = config.icon_theme.as_ref()
             .and_then(|itn| icon_plugin(itn));
-        let mut special_paths = config.special_paths
-            .iter()
-            .map(|(k, v)| path::SpecialPath::new(k.clone(), *v))
-            .collect();
-        path::add_defaults(&mut special_paths);
+        let mut special_paths: SpecialPaths = (&config.special_paths).try_into()?;
+        special_paths.add_defaults();
         let search_modes = config
             .search_modes
             .as_ref()
@@ -181,6 +189,7 @@ impl AppContext {
         let terminal_title_pattern = config.terminal_title.clone();
 
         Ok(Self {
+            is_tty,
             initial_root,
             initial_file,
             initial_tree_options,
@@ -206,6 +215,7 @@ impl AppContext {
             content_search_max_file_size,
             terminal_title_pattern,
             update_work_dir: config.update_work_dir.unwrap_or(true),
+            keyboard_enhanced: false,
         })
     }
     /// Return the --cmd argument, coming from the launch arguments (prefered)
